(this.webpackJsonpstreamlit_component_template=this.webpackJsonpstreamlit_component_template||[]).push([[0],{67:function(e,t,a){e.exports=a(77)},77:function(e,t,a){"use strict";a.r(t);var r=a(5),n=a.n(r),l=a(55),o=a.n(l),s=a(0),c=a(1),i=a(2),p=a(3),d=a(32),m=a(50),u=a(16),g=a(100),b=a(103),h=a(104),v=a(99),E=a(105),f=a(62),j=a.n(f),x=a(61),y=a.n(x),O=a(102),_=["expand"],k=Object(u.a)((function(e){e.expand;var t=Object(d.a)(e,_);return n.a.createElement(v.a,t)}))((function(e){var t=e.theme;return{transform:e.expand?"rotate(180deg)":"rotate(0deg)",marginLeft:"auto",transition:t.transitions.create("transform",{duration:t.transitions.duration.shortest})}})),w=function(e){Object(i.a)(a,e);var t=Object(p.a)(a);function a(){var e;Object(c.a)(this,a);for(var r=arguments.length,l=new Array(r),o=0;o<r;o++)l[o]=arguments[o];return(e=t.call.apply(t,[this].concat(l))).state={active:!1},e.toggleActive=function(){console.log(e.state);var t=e.state.active;e.setState({active:!t}),console.log(e.state)},e.render=function(){var t=e.props.args.title,a=e.props.args.context,r=e.props.args.highlight_start,l=e.props.args.highlight_end,o=e.props.args.score,s=e.props.args.url,c=(e.props.args.key,e.state.active),i=a.slice(0,r),p=a.slice(r,l),d=a.slice(l);return n.a.createElement("div",{style:{padding:"1rem"}},n.a.createElement(g.a,{variant:"outlined"},n.a.createElement(b.a,{title:t,subheader:o}),n.a.createElement(h.a,null,n.a.createElement(O.a,{variant:"body2"},c?i:"",n.a.createElement("span",{style:{fontWeight:c?"bold":"normal",color:c?"#f63366":"#000000"}},p),c?d:"")),n.a.createElement(E.a,{disableSpacing:!0},n.a.createElement(v.a,{disabled:e.props.disabled,"aria-label":"open source url",href:s,target:"_PARENT"},n.a.createElement(y.a,null)),n.a.createElement(k,{expand:c,onClick:e.toggleActive,disabled:e.props.disabled,"aria-expanded":c,"aria-label":"show more"},n.a.createElement(j.a,null)))))},e}return Object(s.a)(a)}(m.a),A=Object(m.b)(w);o.a.render(n.a.createElement(n.a.StrictMode,null,n.a.createElement(A,null)),document.getElementById("root"))}},[[67,1,2]]]);
//# sourceMappingURL=main.25d11891.chunk.js.map